@@ -15,7 +15,7 @@
 # pyDARM. If not, see <https://www.gnu.org/licenses/>.
 
 from . import (sensing, actuation, utils, darm, pcal, measurement, uncertainty,
-               plot, calcs)
+               plot, calcs, FIR, FIRtools)
 
 try:
     from ._version import version as __version__
