@@ -29,13 +29,6 @@ class ActuationModel(Model):
     This is a class to set up the model for the actuation function from a
     configuration file with all the information about where the data is stored
 
-    Parameters
-    ----------
-
-    Returns
-    -------
-
-
     """
 
     def __init__(self, config, measurement):
@@ -62,6 +55,7 @@ class ActuationModel(Model):
         -------
         out : dict, `complex128`, array-like
             transfer function response of the uncompensated driver electronics
+
         """
 
         out = {'UIM': {'UL': np.ones(len(frequencies), dtype='complex128'),
@@ -93,7 +87,8 @@ class ActuationModel(Model):
                         'Using old format for zeros and poles. Please check'
                         ' your configuration string/file and use the'
                         ' updated format to specify'
-                        ' compensted/uncompensated parameters.')
+                        ' compensated/uncompensated parameters. '
+                        f'Stage: {stage.lower()}, Quadrant: {quadrant.lower()}')
 
                 # Start with empty lists for zeros and poles. Extend as needed
                 zeros = []
@@ -143,23 +138,23 @@ class ActuationModel(Model):
         return out
 
     def uim_dc_gain_Apct(self):
-        """
-        This computes the UIM DC gain in units of amps / count
+        """This computes the UIM DC gain in units of amps / count
+
         """
 
         return 4 * 0.25 * self.dac_gain * self.uim_driver_dc_trans_apv
 
     def pum_dc_gain_Apct(self):
-        """
-        This computes the PUM DC gain in units of amps / count
+        """This computes the PUM DC gain in units of amps / count
+
         """
 
         return 4 * 0.25 * self.dac_gain * self.pum_driver_dc_trans_apv * \
             self.pum_coil_outf_signflip
 
     def tst_dc_gain_V2pct(self):
-        """
-        This computes the TST DC gain in units of volts**2 / count
+        """This computes the TST DC gain in units of volts**2 / count
+
         """
 
         return 4 * 0.25 * self.dac_gain * self.tst_driver_dc_gain_vpv_lv * \
@@ -167,8 +162,8 @@ class ActuationModel(Model):
             self.actuation_esd_bias_voltage
 
     def uim_dc_gain_Npct(self):
-        """
-        This computes the UIM DC gain in units of Newtons / count
+        """This computes the UIM DC gain in units of Newtons / count
+
         """
 
         return self.uim_dc_gain_Apct() * self.uim_npa
@@ -181,8 +176,8 @@ class ActuationModel(Model):
         return self.pum_dc_gain_Apct() * self.pum_npa
 
     def tst_dc_gain_Npct(self):
-        """
-        This computes the TST DC gain in units of Newtons / count
+        """This computes the TST DC gain in units of Newtons / count
+
         """
 
         return self.tst_dc_gain_V2pct() * self.tst_npv2
@@ -219,6 +214,7 @@ class ActuationModel(Model):
         uim_drive_align_filter_response : `complex128`, array-like
             transfer function response of the DRIVEALIGN digital filters in the
             UIM path
+
         """
 
         # Start with TST stage filters
@@ -286,6 +282,7 @@ class ActuationModel(Model):
             transfer function response of the digital filters in the PUM path
         tst_digital_filter_response : `complex128`, array-like
             transfer function response of the digital filters in the TST path
+
         """
 
         tst_isc_inf_filter_response, tst_lock_filter_response, \
@@ -332,6 +329,7 @@ class ActuationModel(Model):
         out : dict, `complex128`, array-like
             transfer function response of the digital compensation filters in
             each path and quadrant
+
         """
 
         out = {'UIM': {'UL': np.ones(len(frequencies), dtype='complex128'),
@@ -403,10 +401,8 @@ class ActuationModel(Model):
 
         Parameters
         ----------
-        sus_dict_digital : dict, `complex`, array-like
-            dictionary of digital compensation transfer function values
-        sus_dict_analog : dict, `complex`, array-like
-            dictionary of analog driver transfer function values
+        frequencies : `float`, array-like
+            array of frequencies to compute the response
 
         Returns
         -------
@@ -419,6 +415,7 @@ class ActuationModel(Model):
         tst : dict, `complex128`, array-like
             transfer function response of the digital compensation filters in
             each path and quadrant for the TST
+
         """
 
         sus_dict_digital = self.sus_digital_compensation_response(frequencies)
@@ -462,6 +459,7 @@ class ActuationModel(Model):
         -------
         A_mn_res : `complex128`, array-like
             transfer function response of the residual actuation function
+
         """
 
         # SUS to IOP and IOP to analog digital time delays (see G1601472)
@@ -533,6 +531,7 @@ class ActuationModel(Model):
             transfer function response of the PUM stage
         TST_F2L_freqresp : `complex128`, array-like
             transfer function response of the TST stage
+
         """
 
         mat = io.loadmat(suspension_file)
@@ -566,6 +565,7 @@ class ActuationModel(Model):
             transfer function response of the PUM stage
         tst_response : `complex128`, array-like
             transfer function response of the TST stage
+
         """
 
         # Analog force to length response for each stage from Matlab
@@ -601,7 +601,7 @@ class ActuationModel(Model):
         Euler Basis: positive longitudinal displacement is along a
         vector perpendicular to the plane of the HR surface
         (positive ETMX displacement is in the -X global IFO direction,
-         positive ITMY displacement is in the +Y global IFO direction).
+        positive ITMY displacement is in the +Y global IFO direction).
 
         Parameters
         ----------
@@ -616,6 +616,7 @@ class ActuationModel(Model):
             transfer function response of the PUM stage
         tst_response : `complex128`, array-like
             transfer function response of the TST stage
+
         """
 
         # Digital out to displacement of the TST stage by each of the
@@ -655,11 +656,15 @@ class ActuationModel(Model):
         filter bank of each action stage to DARM by accounting for how
         positive longitudinal drive for each actuation stage pushes the given
         test mass to creates DARM.
+
         DARM displacement is defined by
-        + DARM = + Delta L
-               = (Delta L_X - Delta L_Y)
-               = - (Delta L_EX + Delta L_IX)
-                    + (Delta L_EY + Delta L_IY).
+
+        .. math ::
+
+            + DARM = + Delta L \\
+            = (Delta L_X - Delta L_Y) \\
+            = - (Delta L_EX + Delta L_IX) + (Delta L_EY + Delta L_IY)
+
         This is particularly useful for computing EPICS records
 
         Parameters
@@ -675,6 +680,7 @@ class ActuationModel(Model):
             transfer function response of the PUM stage
         tst_response : `complex128`, array-like
             transfer function response of the TST stage
+
         """
 
         longitudinal_displacement = (
@@ -715,6 +721,7 @@ class ActuationModel(Model):
             transfer function response of the PUM stage, everything but N/ct
         tst_response : `complex128`, array-like
             transfer function response of the TST stage, everything but N/ct
+
         """
 
         [uim_response,
@@ -747,6 +754,7 @@ class ActuationModel(Model):
         -------
         tf : `complex128`, array-like
             transfer function response of the actuation function
+
         """
 
         # Digital output to TST displacement
@@ -799,13 +807,6 @@ class DARMActuationModel(Model):
     This is a class to set up the model for the DARM loop from a
     configuration file with all the information about where the data is stored
 
-    Parameters
-    ----------
-
-    Returns
-    -------
-
-
     """
 
     def __init__(self, config):
@@ -817,8 +818,8 @@ class DARMActuationModel(Model):
             self.yarm = ActuationModel(config, measurement='actuation_y_arm')
 
     def darm_output_matrix_values(self):
-        """
-        Turns the output matrix values into an array for the QUAD SUS
+        """Turns the output matrix values into an array for the QUAD SUS
+
         """
 
         output_matrix = np.zeros((2, 4))
@@ -848,7 +849,7 @@ class DARMActuationModel(Model):
         ----------
         frequencies : `float`, array-like
             array of frequencies to compute the response
-        stage : `str`
+        stage : `str`, optional
             SUS stage for the calculation, 'UIM', 'PUM', or 'TST'
         syserr_dict : `dict`, optional
             dict of multiplicative values, ex.:
@@ -858,6 +859,7 @@ class DARMActuationModel(Model):
         -------
         super_actuation : `complex128`, array-like
             transfer function response of the actuation function
+
         """
 
         output_matrix = self.darm_output_matrix_values()
@@ -900,6 +902,87 @@ class DARMActuationModel(Model):
 
         return super_actuation
 
+    def stage_super_actuator_drivealign(self, frequencies, stage='TST',
+                                        syserr_dict=None):
+        """
+        Compute the super actuator transfer function for a specific stage.
+        In this case, the "stage super actuator" is created by choosing a
+        specific stage and then for each QUAD, the stage transfer function to
+        DARM is summed together.
+
+        This transfer function is from the input of the DRIVEALIGN filter bank
+        to meters sensed by the IFO. This method assumes that the signal
+        feedback to a single stage would be positive, but if the signal is sent
+        to both arms (like a DARM signal) then X and Y are 180 degrees out of
+        phase.
+
+        Parameters
+        ----------
+        frequencies : `float`, array-like
+            array of frequencies to compute the response
+        stage : `str`
+            SUS stage for the calculation, 'UIM', 'PUM', or 'TST'
+        syserr_dict : `dict`, optional
+            dict of multiplicative values, ex.:
+            {'xarm': {'UIM': `complex`, array-like}}
+
+        Returns
+        -------
+        super_actuation : `complex128`, array-like
+            transfer function response of the actuation function
+        """
+
+        assert stage.lower() != 'top', 'top has not been implemented'
+
+        # Get the output matrix values
+        output_matrix = self.darm_output_matrix_values()
+
+        # Get the stage index
+        stage_idx = ['top', 'uim', 'pum', 'tst'].index(stage.lower())
+
+        # We have two scenarios:
+        # 1) Both arms are used for servo control. X and Y arms receive the
+        # same signal but 180 degrees out of phase, so here we end up
+        # SUBTRACTING the Y arm from X arm due to this 180 degrees difference
+        # 2) Only one arm uses feedback control. We want to maintain the
+        # historical infrastructure for single-arm feedback, so we don't
+        # need to account for any signs when combining arm contributions.
+        # There may be a cleaner way to code this...
+        if output_matrix[0, stage_idx] != 0 and output_matrix[1, stage_idx] != 0:
+            # Check that we have attributes for both arms
+            if hasattr(self, 'xarm') is False or hasattr(self, 'yarm') is False:
+                raise ValueError('Must provide an ActuationModel object for both arms')
+
+            xarm_contrib = (
+                self.xarm.drivealign_to_darm_displacement(frequencies)[stage_idx-1])
+            yarm_contrib = (
+                self.yarm.drivealign_to_darm_displacement(frequencies)[stage_idx-1])
+
+            if syserr_dict is not None:
+                if 'xarm' in syserr_dict and stage.upper() in syserr_dict['xarm']:
+                    xarm_contrib *= syserr_dict['xarm'][stage.upper()]
+                if 'yarm' in syserr_dict and stage.upper() in syserr_dict['yarm']:
+                    yarm_contrib *= syserr_dict['yarm'][stage.upper()]
+
+            super_actuation = (xarm_contrib - yarm_contrib)
+        else:
+            for arm_idx, arm in enumerate(['x', 'y']):
+                if output_matrix[arm_idx, stage_idx] != 0.0:
+                    if hasattr(self, f'{arm}arm') is False:
+                        raise ValueError('Must provide an ActuationModel object')
+                    else:
+                        this_arm = getattr(self, f'{arm}arm')
+
+                    super_actuation = this_arm.drivealign_to_darm_displacement(
+                        frequencies)[stage_idx-1]
+
+                    if (syserr_dict is not None and
+                            f'{arm}arm' in syserr_dict and
+                            stage.upper() in syserr_dict[f'{arm}arm']):
+                        super_actuation *= syserr_dict[f'{arm}arm'][stage.upper()]
+
+        return super_actuation
+
     def arm_super_actuator(self, frequencies, arm='x', syserr_dict=None):
         """
         Compute the super actuator transfer function for a specific arm.
@@ -919,7 +1002,7 @@ class DARMActuationModel(Model):
             array of frequencies to compute the response
         arm : `str`
             arm for the calculation, 'x' or 'y'
-        actuation_syserr_dict : `dict`, optional
+        syserr_dict : `dict`, optional
             dict of multiplicative values, ex.:
             {'xarm': {'UIM': `complex`, array-like}}
 
@@ -927,6 +1010,7 @@ class DARMActuationModel(Model):
         -------
         super_actuation : `complex128`, array-like
             transfer function response of the actuation function
+
         """
 
         output_matrix = self.darm_output_matrix_values()
@@ -980,7 +1064,7 @@ class DARMActuationModel(Model):
         ----------
         frequencies : `float`, array-like
             array of frequencies to compute the response
-        actuation_syserr_dict : `dict`, optional
+        syserr_dict : `dict`, optional
             dict of multiplicative values, ex.:
             {'xarm': {'UIM': `complex`, array-like}}
 
@@ -988,6 +1072,7 @@ class DARMActuationModel(Model):
         -------
         tf : `complex128`, array-like
             transfer function response of the actuation function
+
         """
 
         darm_actuation = np.zeros(len(frequencies), dtype='complex128')
