@@ -49,10 +49,10 @@ class CALCSModel(DARMModel):
 
         In T1900169, in the definition of C/C_CALCS, the last three
         terms are
-          (opt resp)/(opt resp)_foton * (LP_foton/LP) * LP
+        .. math :: (opt resp)/(opt resp)_foton * (LP_foton/LP) * LP
         and this method returns this combination since the export from
         FOTON gives the full combination of
-          LP_foton / (opt resp)_foton
+        .. math :: LP_foton / (opt resp)_foton
 
         Note that (LP_foton/LP) is the "IIR warping"
 
@@ -397,7 +397,7 @@ class CALCSModel(DARMModel):
         ----------
         frequencies : `float`, array-like
             array of frequencies to compute the response
-        stage : `str`
+        stage : `str`, optional
             SUS stage for the calculation, 'UIM', 'PUM', or 'TST'
 
         Returns
@@ -439,7 +439,7 @@ class CALCSModel(DARMModel):
         ----------
         frequencies : `float`, array-like
             array of frequencies to compute the response
-        stage : `str`
+        arm : `str`, optional
             SUS stage for the calculation, 'UIM', 'PUM', or 'TST'
 
         Returns
@@ -803,7 +803,7 @@ class CALCSModel(DARMModel):
 
         return calib
 
-    def deltal_ext_pcal_corrrection(self, frequencies, **kwargs):
+    def deltal_ext_pcal_correction(self, frequencies, **kwargs):
         """
         Compute the calibration transfer function, dL_pyDARM / dL_Pcal
         for determining the response function systematic error
@@ -826,10 +826,13 @@ class CALCSModel(DARMModel):
         """
 
         endstation = kwargs.pop('endstation', False)
+        include_dewhitening = kwargs.pop('include_dewhitening', True)
 
         deltal_ext = self.calcs_dtt_calibration(frequencies, **kwargs)
-        pcal_corr = self.pcal.compute_pcal_correction(frequencies,
-                                                      endstation=endstation)
+        pcal_corr = self.pcal.compute_pcal_correction(
+            frequencies,
+            endstation=endstation,
+            include_dewhitening=include_dewhitening)
 
         tf = deltal_ext / pcal_corr
 
