@@ -18,20 +18,22 @@ import numpy as np
 from scipy import signal
 from gwpy.time import tconvert, from_gps
 from epics import caget, caput
+from os.path import normpath
 
 from .model import Model
 from .sensing import SensingModel
 from .actuation import DARMActuationModel
 from .pcal import PcalModel
-from .utils import compute_digital_filter_response, digital_delay_filter
+from .utils import compute_digital_filter_response
 from .digital import daqdownsamplingfilters
 from .plot import critique
 
 
 class DigitalModel(Model):
-    """DARM digital controller model object
+    """DARM digital filter model object
 
     """
+
     def __init__(self, config):
         super().__init__(config, measurement='digital')
 
@@ -79,12 +81,14 @@ class DigitalModel(Model):
 
 
 class DARMModel(Model):
-    """DARM model object
+    """
+    DARM model object
 
     This is a class to set up the model for the DARM loop from a
     configuration file with all the information about where the data is stored
 
     """
+
     def __init__(self, config, sensing=None, actuation=None, digital=None, pcal=None):
         super().__init__(config)
         self.sensing = sensing or SensingModel(config)
@@ -134,6 +138,7 @@ class DARMModel(Model):
         -------
         tf : `complex128`, array-like
             transfer function of the DARM closed-loop response
+
         """
 
         C_response = self.sensing.compute_sensing(frequencies)
@@ -147,8 +152,8 @@ class DARMModel(Model):
         return (1.0/C_response + D_response * A_response)
 
     def compute_epics_records(self, f_pcal1, f_uim, f_pum, f_tst, f_pcal2,
-                              f_pcal3, arm, save_to_file=None,
-                              endstation=False):
+                              f_pcal3, f_pcalx_cmp, f_pcaly_cmp,
+                              save_to_file=None, endstation=False):
         """
         This is a LIGO specific function for generating front end calibration
         and GDS EPICS records. This function is very specific for O3, but we
@@ -172,8 +177,10 @@ class DARMModel(Model):
             Pcal line frequency 2 (the mid-frequency ~400 Hz line)
         f_pcal3 : `float`
             Pcal line frequency 3 (the high-frequency ~1080 Hz line)
-        arm : `str`
-            'x' or 'y' to indicate which arm is used for the SUS actuators
+        f_pcalx_cmp : `float`
+            Pcal line on the x-arm for direct comparison
+        f_pcaly_cmp : `float`
+            Pcal line on the y-arm for direct comparison
         save_to_file : `str`, optional
             Filename (ASCII) to save the values for EPICS from this reference
             model
@@ -191,7 +198,8 @@ class DARMModel(Model):
         """
 
         freq = np.array(
-            [f_pcal1, f_uim, f_pum, f_tst, f_pcal2, f_pcal3])
+            [f_pcal1, f_uim, f_pum, f_tst, f_pcal2, f_pcal3, f_pcalx_cmp,
+             f_pcaly_cmp])
 
         R = self.compute_response_function(freq)
 
@@ -208,30 +216,30 @@ class DARMModel(Model):
             pcal_correction[4] * np.exp(-2*np.pi*1j*freq[4]/16384))
         PCAL_LINE3_CORRECTION = (
             pcal_correction[5] * np.exp(-2*np.pi*1j*freq[5]/16384))
+        # We divide out the pcal reference arm sign since we know which arm
+        # the next two values will be assigned to. This makes the next two
+        # values constant no matter what arm the PCal calibration lines are
+        # assigned to
+        PCAL_X_COMPARE_CORRECTION = (
+            pcal_correction[6] / self.pcal.ref_pcal_2_darm_act_sign *
+            np.exp(-2*np.pi*1j*freq[6]/16384))
+        PCAL_Y_COMPARE_CORRECTION = (
+            -1 * pcal_correction[7] / self.pcal.ref_pcal_2_darm_act_sign *
+            np.exp(-2*np.pi*1j*freq[7]/16384))
 
-        # The actuator lines are injected at the input to the DRIVEALIGN bank
-        # Also get the complete actuation model
-        if arm == 'x':
-            this_arm = self.actuation.xarm
-        elif arm == 'y':
-            this_arm = self.actuation.yarm
-        else:
-            raise ValueError('Must provide value of x or y to argument arm')
+        # this does not include any OMC to SUS model jump delay
+        uim_actuation_epics = self.actuation.stage_super_actuator_drivealign(
+            freq, stage='UIM')
+        pum_actuation_epics = self.actuation.stage_super_actuator_drivealign(
+            freq, stage='PUM')
+        tst_actuation_epics = self.actuation.stage_super_actuator_drivealign(
+            freq, stage='TST')
 
-        [uim_actuation_epics,
-         pum_actuation_epics,
-         tst_actuation_epics] = this_arm.drivealign_to_darm_displacement(freq)
-        uim = this_arm.compute_actuation_single_stage(freq, stage='UIM')
-        pum = this_arm.compute_actuation_single_stage(freq, stage='PUM')
-        tst = this_arm.compute_actuation_single_stage(freq, stage='TST')
-
-        # single stage actuation computation doesn't include the OMC to SUS
-        # delay so we will add that in here
-        omc_to_sus_response = signal.dfreqresp(
-            digital_delay_filter(1, 16384), 2.0*np.pi*freq/16384)[1]
-        uim *= omc_to_sus_response
-        pum *= omc_to_sus_response
-        tst *= omc_to_sus_response
+        # super actuator stage
+        # this does include OMC to SUS model jump delay
+        uim = self.actuation.stage_super_actuator(freq, stage='UIM')
+        pum = self.actuation.stage_super_actuator(freq, stage='PUM')
+        tst = self.actuation.stage_super_actuator(freq, stage='TST')
 
         # Actuator EPICS
         # Need to divide out a DAQ downsampling filter from the reference A
@@ -319,6 +327,10 @@ class DARMModel(Model):
                  PCAL_LINE1_REF_A_UIM.imag,
                  PCAL_LINE3_CORRECTION.real,
                  PCAL_LINE3_CORRECTION.imag,
+                 PCAL_X_COMPARE_CORRECTION.real,
+                 PCAL_X_COMPARE_CORRECTION.imag,
+                 PCAL_Y_COMPARE_CORRECTION.real,
+                 PCAL_Y_COMPARE_CORRECTION.imag,
                  SUS_LINE1_SUS_DEMOD_PHASE,
                  SUS_LINE2_SUS_DEMOD_PHASE,
                  SUS_LINE3_SUS_DEMOD_PHASE))
@@ -356,6 +368,10 @@ class DARMModel(Model):
                  'CAL-CS_TDEP_PCAL_LINE1_REF_A_UIM_IMAG',
                  'CAL-CS_TDEP_PCAL_LINE3_CORRECTION_REAL',
                  'CAL-CS_TDEP_PCAL_LINE3_CORRECTION_IMAG',
+                 'CAL-CS_TDEP_PCAL_X_COMPARE_CORRECTION_REAL',
+                 'CAL-CS_TDEP_PCAL_X_COMPARE_CORRECTION_IMAG',
+                 'CAL-CS_TDEP_PCAL_Y_COMPARE_CORRECTION_REAL',
+                 'CAL-CS_TDEP_PCAL_Y_COMPARE_CORRECTION_IMAG',
                  'CAL-CS_TDEP_SUS_LINE1_SUS_DEMOD_PHASE',
                  'CAL-CS_TDEP_SUS_LINE2_SUS_DEMOD_PHASE',
                  'CAL-CS_TDEP_SUS_LINE3_SUS_DEMOD_PHASE'))
@@ -391,6 +407,8 @@ class DARMModel(Model):
             'CAL-CS_TDEP_PCAL_LINE1_REF_A_PUM': PCAL_LINE1_REF_A_PUM,
             'CAL-CS_TDEP_PCAL_LINE1_REF_A_UIM': PCAL_LINE1_REF_A_UIM,
             'CAL-CS_TDEP_PCAL_LINE3_CORRECTION': PCAL_LINE3_CORRECTION,
+            'CAL-CS_TDEP_PCAL_X_COMPARE_CORRECTION': PCAL_X_COMPARE_CORRECTION,
+            'CAL-CS_TDEP_PCAL_Y_COMPARE_CORRECTION': PCAL_Y_COMPARE_CORRECTION,
             'CAL-CS_TDEP_SUS_LINE1_SUS_DEMOD_PHASE': SUS_LINE1_SUS_DEMOD_PHASE,
             'CAL-CS_TDEP_SUS_LINE2_SUS_DEMOD_PHASE': SUS_LINE2_SUS_DEMOD_PHASE,
             'CAL-CS_TDEP_SUS_LINE3_SUS_DEMOD_PHASE': SUS_LINE3_SUS_DEMOD_PHASE,
@@ -398,7 +416,10 @@ class DARMModel(Model):
 
     def write_epics_records(self, IFO, epics_output, filename, push_to_epics=False):
         """
-        Push EPICS records to the front end CAL-CS model and save to a file
+        Push EPICS records to the front end CAL-CS model and save to a file.
+
+        Note: All EPICS records (real and complex) are casted to 32bit on the fly
+        to avoid downstream issues with the SDF system.
 
         Parameters
         ----------
@@ -411,8 +432,10 @@ class DARMModel(Model):
             path and file name to be written out
         push_to_epics : boolean
             push epics records written to file to the front end epics records
+
         """
 
+        filename = normpath(filename)
         with open(filename, 'w') as f:
             for chname in sorted(epics_output.keys()):
                 chan_val = epics_output[chname]
@@ -420,16 +443,17 @@ class DARMModel(Model):
                 # corresponding channels ending in "_REAL" and
                 # "_IMAG"
                 if np.iscomplex(chan_val):
+                    chan_val = np.complex64(chan_val)
                     chan = [f"{IFO}:{chname}_REAL", f"{IFO}:{chname}_IMAG"]
                     chan_val = [np.real(chan_val), np.imag(chan_val)]
                 else:
                     chan = [f"{IFO}:{chname}"]
-                    chan_val = [chan_val]
+                    chan_val = [np.float32(chan_val)]
                 for idx, ch in enumerate(chan):
-                    f.write(f"{ch} {chan_val[idx]:0.16e}\n")
+                    f.write(f"{ch} {chan_val[idx]:0.6e}\n")
                     if push_to_epics:
                         # using caput_many() would probably be better here
-                        caput(ch, f'{chan_val[idx]:0.16e}', wait=True, timeout=1)
+                        caput(ch, f'{chan_val[idx]:0.6e}', wait=True, timeout=1)
 
         # check if values written to EPICS channels were transferred properly
         # Note: This assumes there is no race condition to write to any of the
@@ -442,11 +466,12 @@ class DARMModel(Model):
                     # split channels if dealing with complex values, same as
                     # above.
                     if np.iscomplex(chan_val):
+                        chan_val = np.complex64(chan_val)
                         chan = [f"{IFO}:{chname}_REAL", f"{IFO}:{chname}_IMAG"]
                         chan_val = [np.real(chan_val), np.imag(chan_val)]
                     else:
                         chan = [f"{IFO}:{chname}"]
-                        chan_val = [chan_val]
+                        chan_val = [np.float32(chan_val)]
                     for idx, ch in enumerate(chan):
                         try:
                             readVal = caget(ch)
@@ -472,8 +497,7 @@ class DARMModel(Model):
             multiplicative factor to include relative sensing systematic error
         actuation_syserr_dict : `dict`, optional
             dict of multiplicative values, ex.:
-            {'xarm': {'UIM': `complex`, array-like},
-             'yarm': {'PUM': `complex`, array-like}}
+            {'xarm': {'UIM': `complex`, array-like}, 'yarm': {'PUM': `complex`, array-like}}
 
         Returns
         -------
@@ -498,42 +522,41 @@ class DARMModel(Model):
                                                actuation_syserr_dict=actuation_syserr_dict) / R
         return eta_R_c, eta_R_a, eta_R
 
-    def plot(self, plot_selection='all', freq_min=0.1, freq_max=5000, filename=None, ifo='',
-             label=None, style=None, ugf_start=10, ugf_end=1000, show=None, **kwargs):
+    def plot(self, plot_selection='all', freq_min=0.1, freq_max=5000,
+             filename=None, ifo='', label=None, style=None, ugf_start=10,
+             ugf_end=1000, show=None, **kwargs):
         """
-        Make DARM critique plots.
+        Make DARM critique plots
+
         This method produces critique models for 1 or 2 models.
 
-        PARAMETERS
+        Parameters
         ----------
-        args: The first argumets should be 1 or 2 darm models.
-                  - darm model object (DARMModel)
+        plot_selection : `str`, optional
+            Select plot type, one of: 'all' (default), 'optical', 'actuation',
+            'clg', 'olg', or 'digital'
+        freq_min : `float`, optional
+            start frequency
+        freq_max : `float`, optional
+            end frequency
+        filename : `str`, optional
+            if given, ALL generated graphs will be saved in one pdf
+        ifo : `str`, optional
+            if given with a model to plot, it will appear in the
+            graph titles
+        label : `str` list, optional
+            FIXME: what should this be?
+        style : `str`, optional
+            one of the styles matplotlib has or a user filename with style
+        ugf_start : `float`, optional
+            start frequency used for the search
+        ugf_end : `float`, optional
+            end frequency used for the search
+        show : `bool`, optional
+            if true the plot(s) will show
+        **kwargs : optional
+            Matplotlib values passed to plots
 
-        The plots produced should be close to the final critique plot, but if
-        one needs something special there are a few options to tw
-        Options for the graphs: - freq_min (float) start frequency
-                                - freq_max (float) end frequency
-                                - **kwargs, you can also use all the available
-                                            matplotlib keywords, but have to be common
-                                            for all graphs.
-                                - filename (string)
-                                  if given, ALL generated graphs will be saved in one pdf.
-                                - ifo (string)
-                                  if given with a model to plot, it will appear in the
-                                  graph titles.
-                                - ugf_start, ugf_end (float)
-                                  frequency range used for the search of the UGF
-                                - greed (bool)
-                                - plot_selection (string)
-                                  'all':
-                                  'optical':
-                                  'actuation':
-                                  'clg':
-                                  'olg':
-                                  'digital':
-        RETURNS
-        -------
-        Plots critique plots of the given darm model, and saves them in one pdf file.
         """
 
         critique(self, freq_min=freq_min, freq_max=freq_max, filename=filename, label=label,
