@@ -23,7 +23,8 @@ import numpy as np
 
 
 def iopdownsamplingfilters(sample_freq_str, filter_calc_method, rcg_ver):
-    """Compute the transfer function for the DAQ downsampling filters
+    """
+    Compute the transfer function for the DAQ downsampling filters
 
     Parameters
     ----------
@@ -33,16 +34,13 @@ def iopdownsamplingfilters(sample_freq_str, filter_calc_method, rcg_ver):
         Filtering method. Choose between 'biquad' and 'df2'
     rcg_ver : `str`
         RCG version. Choose between 'v3' and 'v2' (only needed when also
-specifying '16k' and 'biquad')
+        specifying '16k' and 'biquad')
 
     Returns
     -------
     iopfilter : :obj:`scipy.signal.StateSpace`
         State space object
 
-    Examples
-    --------
-    >>> ss = iopdownsamplingfilters('16k','biquad','v3')
     """
 
     if filter_calc_method == 'biquad':
@@ -232,7 +230,8 @@ specifying '16k' and 'biquad')
 
 
 def daqdownsamplingfilters(from_freq, to_freq, filter_method, rcg_ver):
-    """Compute the transfer function for the DAQ downsampling filters
+    """
+    Compute the transfer function for the DAQ downsampling filters
 
     Parameters
     ----------
@@ -250,9 +249,6 @@ def daqdownsamplingfilters(from_freq, to_freq, filter_method, rcg_ver):
     daq_filter : :obj:`scipy.signal.StateSpace`
         State space object
 
-    Examples
-    --------
-    >>> ss = daqdownsamplingfilters(2**14,2**12,'biquad','v3')
     """
 
     sampleFreqRatio = from_freq / to_freq
