@@ -19,6 +19,7 @@ import numpy as np
 import math
 import emcee
 import json
+import h5py
 from datetime import datetime
 from scipy.signal import freqresp, ZerosPolesGain
 import multiprocessing as mp
@@ -47,7 +48,7 @@ class Measurement(object):
     Parameters
     ----------
     meas_file: string
-        String of the name of the xml file of the measurement.
+        String of the name of the xml/hdf5 file of the measurement.
 
     Returns
     -------
@@ -65,14 +66,19 @@ class Measurement(object):
 
     def __init__(self, meas_file):
         if os.path.exists(meas_file) is not True:
-            raise IOError('The dtt file given does not exist.')
+            raise IOError('The file given does not exist.')
 
         self.filename = meas_file
 
         # Data accessing object. It is called later.
-        self.data_access = dttxml.DiagAccess(meas_file)
+        if meas_file.endswith('.xml'):
+            self.data_access = dttxml.DiagAccess(meas_file)
+        elif meas_file.endswith('.hdf5'):
+            self.data_access = h5py.File(meas_file, 'r')
+        else:
+            raise TypeError('Invalid file type input.')
 
-        # FIXME
+        # FIXME, xml only.
         # For now, I can only access the averages and gps time from the
         # file only after I get the transfer function. There must be
         # a way to get them just after we access the file. For now,
@@ -83,7 +89,7 @@ class Measurement(object):
 
     def get_raw_tf(self, channelA, channelB, cohThresh=0):
         """
-        Given two channels it returns the transfer function from the dtt
+        Given two channels it returns the transfer function from the input
         file. Note that it gives channelB/channelA.
         In addition it populates averages and gps_time, calculates the
         uncertainty from coherence, and rejects data with coherence lower
@@ -117,17 +123,31 @@ class Measurement(object):
             # channelA always means the denominator and channelB is the
             # numerator. This should work for both Swept Sine
             # or FFT (aka broadband) measurements.
-
-            tf_holder = self.data_access.xfer(channelB, channelA)
-            self.averages = tf_holder.averages
-            self.gps_time = tf_holder.gps_second
-            self.bw = tf_holder.BW
-            # Frequency of the measurement in Hz
-            frequencies = np.array(tf_holder.FHz)
-            # Transfer function of B/A, complex array
-            tf = np.array(tf_holder.xfer)
-            # Coherence function of B/A, real array
-            coh = np.array(tf_holder.coh)
+            if hasattr(self.data_access, 'xfer'):
+                tf_holder = self.data_access.xfer(channelB, channelA)
+                self.averages = tf_holder.averages
+                self.gps_time = tf_holder.gps_second
+                self.bw = tf_holder.BW
+                # Frequency of the measurement in Hz
+                frequencies = np.array(tf_holder.FHz)
+                # Transfer function of B/A, complex array
+                tf = np.array(tf_holder.xfer)
+                # Coherence function of B/A, real array
+                coh = np.array(tf_holder.coh)
+            else:
+                tf_holder = self.data_access
+                self.averages = np.int32(tf_holder['parameters']['averages'][()])
+                self.gps_time = np.int32(min(tf_holder[channelB][channelA]['StartTimes'][()]))
+                self.bw = np.float64(tf_holder['parameters']['BW'][()])
+                # Frequencies stored as strings, and need to be cast to float.
+                frequencies = tf_holder[channelB][channelA]['Frequencies'][()].astype(np.float64)
+                tf = tf_holder[channelB][channelA]['TransferFunctions'][()]
+                coh = tf_holder[channelB][channelA]['Coherences'][()]
+            # Create a map that sorts by frequency, as it is not in order by design.
+            indexOrder = np.argsort(frequencies)
+            frequencies = frequencies[indexOrder]
+            tf = tf[indexOrder]
+            coh = coh[indexOrder]
             # Uncertainty from coherence
             unc = np.sqrt((1.0-coh)/(2.0*(coh+1e-6)*self.averages))
             # Find good coherence and intersecting points
@@ -135,7 +155,6 @@ class Measurement(object):
             tf = tf[(coh > cohThresh)]
             unc = unc[(coh > cohThresh)]
             coh = coh[(coh > cohThresh)]
-
             return frequencies, tf, coh, unc
         else:
             raise ValueError('Invalid channel for transfer function.')
@@ -175,6 +194,9 @@ class Measurement(object):
         """
         Method to get the channels in the measurement file.
         Annoyingly, the channels are given in a set.
+
+        For the .hdf5, channels can be swapped around freely, returing the inverse as
+        expected.
         Parameters
         ----------
 
@@ -185,7 +207,12 @@ class Measurement(object):
         channels_B: A python set with all the B (NON-A) channels in the
         measurement file of this object.
         """
-        channels_A, channels_B = self.data_access.channels()
+        if hasattr(self.data_access, 'channels'):
+            channels_A, channels_B = self.data_access.channels()
+        else:
+            channels_A, channels_B = \
+                    np.array(self.data_access['parameters']['channelA'][()]).astype(str), \
+                    np.array(self.data_access['parameters']['channelB'][()]).astype(str)
         return channels_A, channels_B
 
 
@@ -200,9 +227,6 @@ class ProcessMeasurement(object):
     ----------
     config_file : `str`
         This is the *.ini model file to be used to process the measurement data
-    meas_type : `str`
-        meas_type needs to be one of 'sensing', 'actuation_x_arm', or
-        'actuation_y_arm' (needs to match config file section label)
     meas_sensing_or_actuation : `Measurement`
         This is the object that contains the data for either the closed
         loop gain (sensing measurement) or suspension measurement (actuation)
@@ -218,9 +242,9 @@ class ProcessMeasurement(object):
     meas2_cohThresh : `float`, optional
         Coherence threshold that values in measurement 2 must be above to be
         included; valid values in the range [0,1]. (default = 0)
+    json_results_file : `str`, optional
+        Filename for a JSON file
 
-    Returns
-    -------
     """
 
     def __init__(self, config_file, meas_sensing_or_actuation, meas_pcal_to_darm,
@@ -256,9 +280,6 @@ class ProcessMeasurement(object):
         intermediate data products by removing known parameters
         (see G1501518-v21).
 
-        Parameters
-        ----------
-
         Returns
         -------
         frequencies : `float`, array-like
@@ -273,6 +294,7 @@ class ProcessMeasurement(object):
             the transfer function for the offline photon calibrator correction
         processed_measurement_response_unc : `float`, array-like
             relative uncertainty of combined measurement data
+
         """
 
         freq_meas1, tf_meas1, coh_meas1, unc_meas1 = \
@@ -350,6 +372,7 @@ class ProcessMeasurement(object):
             cropped transfer function data
         yerr : `float`, array-like
             cropped uncertainties computed from the coherence values
+
         """
         # Mask the data the is within the frequency band selected by the user
         if fmin is not None and fmax is not None:
@@ -367,7 +390,7 @@ class ProcessMeasurement(object):
 
         return xdata, ydata, yerr
 
-    def _mcmc(self, xdata, ydata, yerr, priors,
+    def _mcmc(self, xdata, ydata, yerr, priors, priors_bound,
               burn_in_steps=1000, steps=9000):
         """
         Run an MCMC over the processed measurement data
@@ -380,6 +403,13 @@ class ProcessMeasurement(object):
             Transfer function data corresponding to the frequency array
         yerr : `float`, array-like
             Absolute error values for each transfer function measurement point
+        priors : `float`, array-like
+            An N x M array of initial values where N is the
+            number of walkers and M is the number of parameters
+        priors_bound : `float`, array-like
+            User-specified boundary of prior distribution, a 2 x M
+            array where the first (second) element of each row
+            corresponds to the lower (upper) bound of each parameter
         burn_in_steps : `int`, optional
             Number of steps in the burn-in phase of the MCMC (default = 1000)
         steps : `int`, optional
@@ -389,6 +419,7 @@ class ProcessMeasurement(object):
         -------
         chain : `float`, array-like
             The results of the MCMC chain
+
         """
 
         # Set the numpy parallelization to a single thread because
@@ -405,7 +436,8 @@ class ProcessMeasurement(object):
             sampler = emcee.EnsembleSampler(len(priors[:, 0]),
                                             len(priors[0, :]),
                                             _ln_prob,
-                                            pool=pool)
+                                            pool=pool,
+                                            kwargs={'bound': priors_bound})
             # This is burn-in, but I wonder if there is a better way to do
             # this using the v3 of emcee. There are some optional arguments
             # when calling like 'flat','thin','discard'
@@ -447,8 +479,6 @@ class ProcessMeasurement(object):
         measurement : str
             measurement type; one of 'sensing', 'actuation_x_arm', or 'actuation_y_arm'
 
-        Returns
-        -------
         """
         # Prepare the new dict for the JSON archive
         now = datetime.now()
@@ -476,6 +506,7 @@ class ProcessMeasurement(object):
 
         # Either read in and make an addition to the JSON archive or create
         # the file if it didn't exist
+        filename = os.path.normpath(filename)
         if os.path.exists(filename):
             # JSON doesn't like to read/write files in append mode for some
             # reason
@@ -522,10 +553,12 @@ class ProcessMeasurement(object):
         is_pro_spring : bool
             parameter for whether the fit assumed anti-spring (False) or
             pro-spring (True)
+
         """
 
         # Load the data from the specified JSON file
-        with open(self.json_results_file, 'r') as f:
+        json_results_file = os.path.normpath(self.json_results_file)
+        with open(json_results_file, 'r') as f:
             data = json.load(f)
 
         # Loop through the analyis entries, looking for only the results with
@@ -644,6 +677,7 @@ class ProcessMeasurement(object):
             Standard deviation for the GPR
         cov : `float`, array-like
             Covariance matrix for the GPR
+
         """
 
         # Now clean up, extract, and get in the right shape for the GPR
@@ -704,9 +738,9 @@ class ProcessSensingMeasurement(ProcessMeasurement):
     meas2_cohThresh : `float`, optional
         Coherence threshold that values in measurement 2 must be above to be
         included; valid values in the range [0,1]. (default = 0)
+    json_results_file : `str`, optional
+        Filename of a JSON file
 
-    Returns
-    -------
     """
 
     def __init__(self, config_file, meas_clg, meas_pcal_to_darm, meas_tup_1,
@@ -724,10 +758,6 @@ class ProcessSensingMeasurement(ProcessMeasurement):
         from the DTT files specified in the object and computes the measurement
         response by removing known parameters (see G1501518-v21).
 
-        Parameters
-        ----------
-        Arguments are passed directly to rescale_sensing_by_tdcf_vals
-
         Returns
         -------
         frequencies : `float`, array-like
@@ -737,6 +767,7 @@ class ProcessSensingMeasurement(ProcessMeasurement):
             of digital counts per meter of DARM
         processed_measurement_response_unc : `float`, array-like
             relative uncertainty of processed measurement data
+
         """
 
         # First get the intermediate data products from the measurement
@@ -784,6 +815,7 @@ class ProcessSensingMeasurement(ProcessMeasurement):
         -------
         response : `complex128`, array-like
             The scaled transfer function of optical response
+
         """
 
         # Important note: the attribute for SensingModel are actually all
@@ -810,7 +842,8 @@ class ProcessSensingMeasurement(ProcessMeasurement):
 
         return response
 
-    def run_mcmc(self, fmin=None, fmax=None, save_to_file=None, **kwargs):
+    def run_mcmc(self, fmin=None, fmax=None, priors_bound=None,
+                 save_to_file=None, **kwargs):
         """
         This method is what is used to process the sensing function measurement
         data
@@ -823,10 +856,19 @@ class ProcessSensingMeasurement(ProcessMeasurement):
         fmax : `float`, optional
             Optional maximum frequency value for the MCMC fitting. Default is
             the maximum frequency of xdata (default = None)
+        priors_bound: `float`, array-like, optional
+            User-specified boundary of prior distribution. Default boundaries
+            are only for spring freq (must be within this range
+            0.0<spring freq<20.0) and inv Q (must be within this range
+            1.e-2<inv Q<1.0).
+            If choosing a different set of boundaries, then this argument
+            should be in form of a 2D array, 5X2. First (second) element of
+            each row corresponds to the lower (upper) bound of each
+            parameters: gain, pole freq, spring freq, inv Q, residual delay.
         save_to_file : `str`, optional
             Filename (JSON) to save the data from this result
-
-        other kwargs are passed to ProcessMeasurement._mcmc
+        kwargs : optional
+            other kwargs are passed to ProcessMeasurement._mcmc
 
         Returns
         -------
@@ -837,6 +879,7 @@ class ProcessSensingMeasurement(ProcessMeasurement):
             - 2 is the optical spring frequency in units of Hz
             - 3 is the quality factor of the optical spring (Q, unitless)
             - 4 is the residual time delay in units of seconds
+
         """
         global meas_type_gl, is_pro_spring_gl
         meas_type_gl = self.meas_type
@@ -868,7 +911,7 @@ class ProcessSensingMeasurement(ProcessMeasurement):
             np.random.uniform([1., 0.01, -61.e-6], [10., 0.05, 61.e-6],
                               size=(nwalkers, 3))))
 
-        chain = self._mcmc(xdata, ydata, yerr, priors, **kwargs)
+        chain = self._mcmc(xdata, ydata, yerr, priors, priors_bound, **kwargs)
 
         # Fix 1/Q ==> Q
         chain[:, 3] = 1/chain[:, 3]
@@ -890,8 +933,6 @@ class ProcessSensingMeasurement(ProcessMeasurement):
         mcmc_chain : `float`, array-like
             The result from the run_mcmc() method
 
-        Returns
-        -------
         """
 
         MAP_values = np.median(mcmc_chain, axis=0)
@@ -1007,6 +1048,7 @@ class ProcessSensingMeasurement(ProcessMeasurement):
         -------
         output : list
             list of normalized measurements
+
         """
         assert ((len(measurement_list) == len(fmin_list) and
                  len(measurement_list) == len(fmax_list)) or
@@ -1098,6 +1140,7 @@ class ProcessSensingMeasurement(ProcessMeasurement):
             Covariance matrix for the GPR
         residuals : `complex128`, array-like
             residuals of the list of measurements
+
         """
         assert ((len(measurement_list) == len(fmin_list) and
                  len(measurement_list) == len(fmax_list)) or
@@ -1171,9 +1214,9 @@ class ProcessActuationMeasurement(ProcessMeasurement):
     meas2_cohThresh : `float`, optional
         Coherence threshold that values in measurement 2 must be above to be
         included; valid values in the range [0,1]. (default = 0)
+    json_results_file : `str`, optional
+        Filename of a JSON file
 
-    Returns
-    -------
     """
 
     def __init__(self, config_file, meas_type, meas_sus_exc_to_darm, meas_pcal_to_darm,
@@ -1194,9 +1237,6 @@ class ProcessActuationMeasurement(ProcessMeasurement):
         from the DTT files specified in the object and computes the measurement
         response by removing known parameters (see G1501518-v21).
 
-        Parameters
-        ----------
-
         Returns
         -------
         frequencies : `float`, array-like
@@ -1207,6 +1247,7 @@ class ProcessActuationMeasurement(ProcessMeasurement):
             the units will be in N/V**2
         processed_measurement_response_unc : `float`, array-like
             relative uncertainty of processed measurement data
+
         """
 
         # First get the intermediate data products from the measurement
@@ -1252,11 +1293,13 @@ class ProcessActuationMeasurement(ProcessMeasurement):
             measurement. The data is divided by this number, so if anything
             other than the default value is provided, the data will be scaled
             differently (default = 1)
+
         """
 
         return response / kappa_Ai
 
-    def run_mcmc(self, fmin=None, fmax=None, save_to_file=None, **kwargs):
+    def run_mcmc(self, fmin=None, fmax=None, priors_bound=None,
+                 save_to_file=None, **kwargs):
         """
         This method is what is used to process the actuation function
         measurement data
@@ -1269,8 +1312,17 @@ class ProcessActuationMeasurement(ProcessMeasurement):
         fmax : `float`, optional
             Optional maximum frequency value for the MCMC fitting. Default is
             the maximum frequency of xdata (default = None)
-
-        other kwargs are passed to ProcessMeasurement._mcmc
+        priors_bound: `float`, array-like, optional
+            User-specified boundary of prior distribution. Default boundary
+            is only for gain, gain must be larger or equal to 0.0.
+            If choosing a different set of boundaries, then this argument
+            should be in form of a 2D array, 2X2. First (second) element of
+            each row corresponds to the lower (upper) bound of each
+            parameters: gain, residual delay.
+        save_to_file : `str`, optional
+            Filename (JSON) to save the data from this result
+        kwargs : optional
+            other kwargs are passed to ProcessMeasurement._mcmc
 
         Returns
         -------
@@ -1279,6 +1331,7 @@ class ProcessActuationMeasurement(ProcessMeasurement):
             - 0 is the gain in units of newtons per driver output (amps or
             volts**2). For example, for TST the units will be in N/V**2.
             - 1 is the residual time delay in units of seconds
+
         """
         global meas_type_gl
         meas_type_gl = self.meas_type
@@ -1307,7 +1360,7 @@ class ProcessActuationMeasurement(ProcessMeasurement):
                              size=(nwalkers, 1)),
             np.random.uniform(-61.e-6, 61.e-6, size=(nwalkers, 1))))
 
-        chain = self._mcmc(xdata, ydata, yerr, priors, **kwargs)
+        chain = self._mcmc(xdata, ydata, yerr, priors, priors_bound, **kwargs)
 
         if save_to_file is not None:
             self.save_results_to_json(
@@ -1346,6 +1399,7 @@ class ProcessActuationMeasurement(ProcessMeasurement):
         -------
         output : list
             list of normalized measurements
+
         """
         assert ((len(measurement_list) == len(fmin_list) and
                  len(measurement_list) == len(fmax_list)) or
@@ -1419,6 +1473,7 @@ class ProcessActuationMeasurement(ProcessMeasurement):
             Covariance matrix for the GPR
         residuals : `complex128`, array-like
             residuals of the list of measurements
+
         """
         assert ((len(measurement_list) == len(fmin_list) and
                  len(measurement_list) == len(fmax_list)) or
@@ -1457,18 +1512,27 @@ class ProcessActuationMeasurement(ProcessMeasurement):
         return y_pred, sigma, cov, residuals
 
 
-def _ln_prob(pars):
+def _ln_prob(pars, bound=None):
     """
     This is a helper function for the MCMC analysis and not intended for
     general use
 
     See https://emcee.readthedocs.io
+
     """
 
     if meas_type_gl == 'sensing':
-        if (pars[2] < 0.0 or pars[2] > 20.0 or pars[3] < 1e-2 or
-                pars[3] > 1.0):
-            return -np.inf
+        if bound is None:
+            if (pars[2] < 0.0 or pars[2] > 20.0 or pars[3] < 1e-2 or
+                    pars[3] > 1.0):
+                return -np.inf
+        else:
+            if (pars[0] < bound[0][0] or pars[0] > bound[0][1] or
+                    pars[1] < bound[1][0] or pars[1] > bound[1][1] or
+                    pars[2] < bound[2][0] or pars[2] > bound[2][1] or
+                    pars[3] < bound[3][0] or pars[3] > bound[3][1] or
+                    pars[4] < bound[4][0] or pars[4] > bound[4][1]):
+                return -np.inf
         this_response = (pars[0] *
                          freqresp(
                              SensingModel.optical_response(pars[1],
@@ -1479,8 +1543,13 @@ def _ln_prob(pars):
                          np.exp(-2.*np.pi*1j*pars[4] * xdata_gl))
     elif (meas_type_gl == 'actuation_x_arm'
           or meas_type_gl == 'actuation_y_arm'):
-        if pars[0] <= 0.0:
-            return -np.inf
+        if bound is None:
+            if pars[0] <= 0.0:
+                return -np.inf
+        else:
+            if (pars[0] < bound[0][0] or pars[0] > bound[0][1] or
+                    pars[1] < bound[1][0] or pars[1] > bound[1][1]):
+                return -np.inf
         this_response = (pars[0] *
                          np.exp(-2.*np.pi*1j*pars[1] * xdata_gl))
     return np.sum(_log_norm_pdf(ydata_gl, this_response, yerr_gl))
@@ -1497,6 +1566,7 @@ def _log_norm_pdf(x, mu, sigma):
     and that sigma is the standard deviation for the Gaussian in each of the two
     dimensions. Here `x` are the data values, `mu` are the expected values,
     and `sigma` are the absolute error values (not relative error)
+
     """
     return -0.5*abs((x-mu)/sigma)**2 - np.log(2.0*np.pi*sigma**2)
 
@@ -1531,6 +1601,7 @@ def _isin(element, test_elements, rel_tol=1e-09, abs_tol=0.0):
     isin : `boolean`, array-like
         Has the same shape as element. The values element[isin] are in
         test_elements
+
     """
 
     isin = np.empty(element.shape, dtype=bool)
