@@ -73,8 +73,8 @@ class Model(object):
         try:
             if type(config) is dict:
                 self._config.read_dict(config)
-            elif os.path.exists(config):
-                with open(config) as f:
+            elif os.path.exists(os.path.normpath(config)):
+                with open(os.path.normpath(config)) as f:
                     self._config.read_file(f)
             else:
                 self._config.read_string(config)
@@ -255,13 +255,11 @@ class Model(object):
         Return a nested dict of the model configuration. Sections are dict
         in of themselves
 
-        Parameters
-        ----------
-
         Returns
         -------
         out : dict
             dictionary of the model parameters
+
         """
         out = {}
 
@@ -294,6 +292,7 @@ class Model(object):
         -------
         tf : `complex128`, array-like
             transfer function response of the analog AA or AI filter
+
         """
         if hasattr(self, 'analog_anti_aliasing_file') and idx is None:
             path = self.analog_anti_aliasing_file
@@ -317,6 +316,7 @@ class Model(object):
         -------
         tf : `complex128`, array-like
             transfer function response of the digital filter
+
         """
         if hasattr(self, 'anti_aliasing_rate_string'):
             rate_string = self.anti_aliasing_rate_string
