@@ -29,12 +29,6 @@ class PcalModel(Model):
     to the response when pulling the PCAL channels from
     the frames, or establishing force coefficients.
 
-    Parameters
-    ----------
-
-    Returns
-    -------
-
     """
 
     def __init__(self, config):
@@ -44,7 +38,7 @@ class PcalModel(Model):
         """
         Compute the dewhitening response
 
-         Parameters
+        Parameters
         ----------
         frequencies : `float`, array-like
             array of frequencies to compute the response
@@ -53,6 +47,7 @@ class PcalModel(Model):
         -------
         tf : `complex128`, array-like
             transfer function response of the Pcal dewhitening filter
+
         """
 
         filt = signal.ZerosPolesGain(
@@ -61,7 +56,8 @@ class PcalModel(Model):
 
         return signal.freqresp(filt, 2.0*np.pi*frequencies)[1]
 
-    def compute_pcal_correction(self, frequencies, endstation=False):
+    def compute_pcal_correction(self, frequencies, endstation=False,
+                                include_dewhitening=True):
         """
         Compute the Pcal correction for the offline analysis
         See G1501518
@@ -75,16 +71,23 @@ class PcalModel(Model):
             When false (default), the correction is computed for CAL-CS
             PCAL channel, which includes 1 16k clock cycle delay that we must
             compensate (undo). Otherwise, when true, the correction is computed
-            at the end station, which does not include 1 16k clock cycle delay.
+            at the end station, which does not include 1 16k clock cycle delay
+        include_dewhitening : `bool`, optional
+            if the dewhitening filter is on (default), then the correction will
+            include the two 1 Hz poles
 
         Returns
         -------
         tf : `complex128`, array-like
             transfer function response of the correction
+
         """
 
         pcal_sign = self.ref_pcal_2_darm_act_sign
-        pcal_dewhitening = self.pcal_dewhiten_response(frequencies)
+
+        pcal_dewhitening = 1
+        if include_dewhitening:
+            pcal_dewhitening = self.pcal_dewhiten_response(frequencies)
 
         pcal_analog_aa = self.analog_aa_or_ai_filter_response(frequencies)
         # As per the Pcal correction factor shown in G1501518, the front end
@@ -124,6 +127,7 @@ class PcalModel(Model):
         -------
         tf : `complex128`, array-like
             transfer function response of the correction
+
         """
 
         response = np.ones(len(frequencies), dtype='complex128')
