@@ -52,34 +52,37 @@ class BodePlot:
     """bode plotting object
 
     """
-    def __init__(self, fig=None, title=None, figsize=(12, 8), only=''):
+    def __init__(self, fig=None, title=None, figsize=(12, 8), only='', spspec=[211, 212]):
         """
-        PARAMETERS
+        Parameters
         ----------
         only (string): if set to 'mag' or 'phase', this object will only
         plot magnitude or phase, and not the usual 2x1 body plot.
 
-        NOTES
+        Notes
         -----
 
         """
         self.fig = fig or plt.figure(figsize=figsize)
         self.only = only
 
+        self.phase_yticks = np.arange(-180, 180+30, 30)
+        self.phase_ylim = (-185, 185)
+
         if self.only == '':
-            self.ax_mag = self.fig.add_subplot(211)
+            self.ax_mag = self.fig.add_subplot(spspec[0])
             self.ax_mag.grid(True)
             self.ax_mag.grid(which='minor', axis='both', linestyle='--')
             # self.ax_mag.axhline(1, color='k', linestyle='dashed')
             self.ax_mag.set_ylabel('Magnitude')
 
-            self.ax_phase = self.fig.add_subplot(212)
+            self.ax_phase = self.fig.add_subplot(spspec[1])
             self.ax_phase.grid(True)
             self.ax_phase.grid(which='minor', axis='both', linestyle='--')
-            self.ax_phase.set_yticks(np.arange(-180, 180+30, 30))
+            self.ax_phase.set_yticks(self.phase_yticks)
             self.ax_phase.set_ylabel('Phase [deg]')
             self.ax_phase.set_xlabel('Frequency [Hz]')
-            self.ax_phase.set_ylim(-185, 185)
+            self.ax_phase.set_ylim(self.phase_ylim)
 
         if self.only == 'mag' or self.only == 'magnitude':
             self.ax_mag = self.fig.add_subplot(111)
@@ -93,16 +96,19 @@ class BodePlot:
             self.ax_phase = self.fig.add_subplot(111)
             self.ax_phase.grid(True)
             self.ax_phase.grid(which='minor', axis='both', linestyle='--')
-            self.ax_phase.set_yticks(np.arange(-180, 180+30, 30))
+            self.ax_phase.set_yticks(self.phase_yticks)
             self.ax_phase.set_ylabel('Phase [deg]')
             self.ax_phase.set_xlabel('Frequency [Hz]')
-            self.ax_phase.set_ylim(-185, 185)
+            self.ax_phase.set_ylim(self.phase_ylim)
 
         if title:
             self.fig.suptitle(title, y=0.9)
 
     def plot(self, freq, tf, **kwargs):
-        """add frequency response to plot"""
+        """add frequency response to plot
+
+        """
+
         if self.only == '' or self.only == 'mag' or self.only == 'magnitude':
             self.ax_mag.loglog(freq, np.abs(tf), **kwargs)
         if self.only == '' or self.only == 'phase':
@@ -111,7 +117,9 @@ class BodePlot:
     def error(self, freq, tf, tf_error, **kwargs):
         """add frequency response to plot with error
            Note: Error should be relative.
+
         """
+
         if self.only == '' or self.only == 'mag' or self.only == 'magnitude':
             self.ax_mag.errorbar(freq, np.abs(tf), np.abs(tf)*tf_error, **kwargs)
             self.ax_mag.set_xscale('log')
@@ -120,24 +128,42 @@ class BodePlot:
             self.ax_phase.errorbar(freq, np.angle(tf, deg=True), tf_error*180/np.pi, **kwargs)
             self.ax_phase.set_xscale('log')
             self.ax_phase.set_yscale('linear')
+            self.ax_phase.set_yticks(self.phase_yticks)
+
+    def legend(self, labels=None):
+        """add legend
+        """
 
-    def legend(self, labels):
-        """add legend"""
         if self.only == '' or self.only == 'mag' or self.only == 'magnitude':
-            self.ax_mag.legend(labels)
+            if labels:
+                self.ax_mag.legend(labels)
+            else:  # labels can also be passed as kwargs to plot, in which case this is fine
+                self.ax_mag.legend()
         if self.only == 'phase':
-            self.ax_phase.legend(labels)
+            if labels:
+                self.ax_mag.legend(labels)
+            else:
+                self.ax_phase.legend()
 
     def save(self, path):
-        """save bode plot to file"""
+        """save bode plot to file
+
+        """
+
         self.fig.savefig(path)
 
     def show(self):
-        """show interactive plot"""
+        """show interactive plot
+
+        """
+
         plt.show()
 
     def xlim(self, freq_min, freq_max):
-        """set min max for frequency axis"""
+        """set min max for frequency axis
+
+        """
+
         if self.only == '' or self.only == 'mag' or self.only == 'magnitude':
             self.ax_mag.set_xlim(freq_min, freq_max)
             self.autoscale_mag_y()
@@ -145,21 +171,30 @@ class BodePlot:
             self.ax_phase.set_xlim(freq_min, freq_max)
 
     def ylim(self, mag_min, mag_max, phase_min=-185, phase_max=185):
-        """set min max for the magnitude (and phase) axis"""
+        """set min max for the magnitude (and phase) axis
+
+        """
+
         if self.only == '' or self.only == 'mag' or self.only == 'magnitude':
             self.ax_mag.set_ylim(mag_min, mag_max)
         if self.only == '' or self.only == 'phase':
             self.ax_phase.set_ylim(phase_min, phase_max)
 
-    def vlines(self, vfreq):
-        """add vertical line at specific frequency in both mag and phase plot"""
+    def vlines(self, vfreq, color='red', lw=1.0, linestyle='--', label="_nolegend_"):
+        """add vertical line at specific frequency in both mag and phase plot
+
+        """
+
         if self.only == '' or self.only == 'mag' or self.only == 'magnitude':
-            self.ax_mag.axvline(vfreq, color='red', lw=1.0, linestyle='--', label='_nolegend_')
+            self.ax_mag.axvline(vfreq, color=color, lw=lw, linestyle=linestyle, label=label)
         if self.only == '' or self.only == 'phase':
-            self.ax_phase.axvline(vfreq, color='red', lw=1.0, linestyle='--', label='_nolegend_')
+            self.ax_phase.axvline(vfreq, color=color, lw=lw, linestyle=linestyle, label=label)
 
     def text(self, x, y, plot_text):
-        """add text in plot"""
+        """add text in plot
+
+        """
+
         if self.only == '' or self.only == 'mag' or self.only == 'magnitude':
             self.ax_mag.text(x, y, plot_text)
         if self.only == 'phase':
@@ -167,7 +202,9 @@ class BodePlot:
 
     def autoscale_mag_y(self, margin=0.1):
         """This function rescales the y-axis based on the data that is visible given
-        the current xlim of the axis."""
+        the current xlim of the axis.
+
+        """
 
         def get_bottom_top(line):
             xd = np.array(line.get_xdata())
@@ -190,7 +227,10 @@ class BodePlot:
         self.ax_mag.set_ylim(bot, top)
 
     def greed(self, more_minor=True):
-        """add a finer grid than the default"""
+        """add a finer grid than the default
+
+        """
+
         if self.only == '' or self.only == 'mag' or self.only == 'magnitude':
             self.ax_mag.yaxis.set_major_locator(plticker.LogLocator(base=10, numticks=200))
             if more_minor:
@@ -212,48 +252,55 @@ def plot(*args, freq_min=0.1, freq_max=5000, freq_points=1001, filename=None,
     """
     This method provides a simple way to plot quickly anything you want.
 
-    PARAMETERS
+    Parameters
     ----------
-    args: Here you can input any kind of transfer function related data.
-          It accepts multiple sets in multiple formats.
-          FORMATS: - 2-tuple (freq,transfer function)
-                - 3-tuple (freq,transfer function, rel unc)
-                - 4-tuple (freq,transfer function, coherence, rel unc)
-                - freq, transfer function (two lists or 1d arrays separated by comma)
-                - method that returns a transfer function
-                  e.g. D.compute_darm_olg
-                  (assuming D is a darm model object)
+    args : tuple, lists
+        Here you can input any kind of transfer function related data.
+        It accepts multiple sets in multiple formats.
+        FORMATS:
+        - 2-tuple (freq,transfer function)
+        - 3-tuple (freq,transfer function, rel unc)
+        - 4-tuple (freq,transfer function, coherence, rel unc)
+        - freq, transfer function (two lists or 1d arrays separated by comma)
+        - method that returns a transfer function e.g. D.compute_darm_olg
+        (assuming D is a darm model object)
+    freq_min : `float`, optional
+        start frequency
+    freq_max : `float`, optional
+        end frequency
+    freq_points : `int`, optional
+        number of points to calculate
+    filename : `str`, optional
+        if given, ALL generated graphs will be saved in one pdf.
+    mag_min : `float`, optional
+        minimum magnitude scale
+    mag_max : `float`, optional
+        maximum magnitude scale
+    phase_min : `float`, optional
+        minimum phase scale
+    phase_max : `float`, optional
+        maximum phase scale
+    label : `str` list, optional
+        legend string for the data sets given e.g. ['first data', 'second']
+    title : `str`, optional
+        title of the graph
+    style : `str`, optional
+        one of the styles matplotlib has or a user filename with style
+    show : `bool`, optional
+        if true the plot will show
+    greed : `bool`, optional
+        if true a finer grid is drawn for all figs
+    figsize : `float` tuple, optional
+        figure size
+    **kwargs
+        matplotlib arguments passed to all plots
 
-    Options for the graphs: - freq_min (float) start frequency
-                - freq_max (float) end frequency
-                - freq_points (int) number of points to calculate
-                - filename (string)
-                  if given, ALL generated graphs will be saved in one pdf.
-                - mag_min (float) minimum magnitude scale
-                - mag_max (float) maximum magnitude scale
-                - phase_min (float) minimum phase scale
-                - phase_max (float) maximum phase scale
-                - label (list of strings)
-                  legend string for the data sets given
-                  e.g. ['first data', 'second']
-                - title (str) title of the graph
-                - style (str) one of the styles matplotlib has
-                  or a user filename with style
-                - show (boolean) if true the plot will show
-                - greed (boolean) if true a finer grid is drawn for all figs
-                - figsize: figure size
-                - **kwargs, you can also use all the available
-                  matplotlib keywords, but have to be common
-                  for all graphs.
-    RETURNS
+    Returns
     -------
-    Plots all data sets in one graph.
-    Give a filename, if you want to save a pdf of your plots.
-    ALSO RETURNS HANDLE OF BODY PLOT
+    bp : `pydarm.plot.BodePlot` object
 
-    NOTES
-    -----
     """
+
     if filename:
         plt.close('all')
     if style:
@@ -333,12 +380,54 @@ def residuals(freq_model, tf_model, freq_data, tf_data, unc_data,
               phase_major_tick=2, phase_minor_tick=0.5,
               filename=None, show=None, plot_input=False):
     """
-    EXAMPLE USAGE
-    measurement_tuple = freq_data, tf_data, unc_data
-    plot(freq_model, tf_model, measurement_tuple,
-         freq_min=freq_data[0], freq_max=freq_data[-1],
-         title='Measurement vs Model')
+    This method provides a simple way to plot quickly anything you want.
+
+    Parameters
+    ----------
+    freq_model : `float`, array-like
+        frequencies that the model transfer function is computed
+    tf_model : `complex`, array-like
+        transfer function response values at the `freq_model` points
+    freq_data : `float`, array-like
+        frequencies that the measured transfer function data values are
+        computed at
+    tf_data : `complex`, array-like
+        measured transfer function response values at the `freq_daata` points
+    unc_data : `float`, array-like
+        relative uncertainty values, determined from the measurement coherence
+    mag_min : `float`, optional
+        minimum magnitude scale
+    mag_max : `float`, optional
+        maximum magnitude scale
+    phase_min : `float`, optional
+        minimum phase scale
+    phase_max : `float`, optional
+        maximum phase scale
+    mag_major_tick : `float`, optional
+        major tick placement for the magnitude plot
+    mag_minor_tick : `float`, optional
+        minor tick placement for the magnitude plot
+    phase_major_tick : `float`, optional
+        major tick placement for the phase plot
+    phase_minor_tick : `float`, optional
+        minor tick placement for the phase plot
+    filename : `str`, optional
+        save the plot to this file
+    show : `bool`, optional
+        if true the plot will show
+    plot_input : `bool`, optional
+        FIXME: what does this do?
+
+    Notes
+    -----
+    Example usage:
+    >>> measurement_tuple = freq_data, tf_data, unc_data
+    >>> plot(freq_model, tf_model, measurement_tuple,
+    ... freq_min=freq_data[0], freq_max=freq_data[-1],
+    ... title='Measurement vs Model')
+
     """
+
     # First interpolate the model tf at the frequencies of the data points
     tf_model_interp = np.interp(freq_data, freq_model, tf_model)
     tf_ratio = tf_data/tf_model_interp
@@ -371,18 +460,21 @@ def residuals(freq_model, tf_model, freq_data, tf_data, unc_data,
 def get_ugf(freq, tf, search_start=5., search_end=1000., n_points=10000):
     """
     Very non-fancy function for easily finding UGF in the simplest of cases.
-    PARAMETERS
+
+    Parameters
     ----------
     freq: (float) array of frequencies corresponding to the given tf
     tf: (complex) array of the transfer function you want the ugf of
     search_start: (float) frequency to start UGF search
     search_end: (float) frequency to end UGF search
     n_points: (int) increase for increased accuracy of UGF frequency
-    RETURNS
+
+    Returns
     -------
     2-tuple float: UGF frequency, phase margin
 
     """
+
     mag = np.abs(tf)
     phase = np.angle(tf)*180/np.pi
     f_mag = interp1d(freq, mag, kind='cubic', fill_value="extrapolate")
@@ -399,7 +491,8 @@ def get_ugf(freq, tf, search_start=5., search_end=1000., n_points=10000):
 
 
 def save_multifig(filename, figs=None, dpi=200):
-    """ method to save all existing (or list of given) figures in one pdf file
+    """method to save all existing (or list of given) figures in one pdf file
+
     """
 
     pp = PdfPages(filename)
@@ -416,42 +509,36 @@ def critique(*args, filename=None, plot_selection='all', ifo='', show=None,
     """
     This method produces critique models for 1 or 2 models.
 
-    PARAMETERS
+    Parameters
     ----------
-    args: The first argumets should be 1 or 2 darm models.
-              - darm model object (DARMModel)
+    args : `pydarm.darm.DARMModel` object
+        1 or 2 darm models objects, if more than 1, this should be a list
+    filename : `str`, optional
+        if given, ALL generated graphs will be saved in one pdf
+    plot_selection : `str`, optional
+        Select plot type, one of: 'all' (default), 'optical', 'actuation',
+        'clg', 'olg', or 'digital'
+    ifo : `str`, optional
+        if given with a model to plot, it will appear in the graph titles
+    show : `bool`, optional
+        if true the plot(s) will show
+    label : `str` list, optional
+        FIXME: what should this be?
+    freq_min : `float`, optional
+        start frequency
+    freq_max : `float`, optional
+        end frequency
+    freq_points : `int`, optional
+        Number of frequency points
+    ugf_start : `float`, optional
+        start frequency used for the search
+    ugf_end : `float`, optional
+        end frequency used for the search
+    greed : `bool`, optional
+    figsize : `float`, tuple
+    **kwargs : optional
+        Matplotlib values passed to plots
 
-    The plots produced should be close to the final critique plot, but if
-    one needs something special there are a few options to tweak
-    Options for the graphs: - freq_min (float) start frequency
-                            - freq_max (float) end frequency
-                            - freq_points (int) number of points to calculate
-                            - label (list of strings)
-                            - **kwargs, you can also use all the available
-                                        matplotlib keywords, but have to be common
-                                        for all graphs.
-                            - filename (string)
-                              if given, ALL generated graphs will be saved in one pdf.
-                            - ifo (string)
-                              if given with a model to plot, it will appear in the
-                              graph titles.
-                            - ugf_start, ugf_end (float)
-                              frequency range used for the search of the UGF
-                            - greed (bool)
-                            - plot_selection (string)
-                              'all':
-                              'optical':
-                              'actuation':
-                              'clg':
-                              'olg':
-                              'digital':
-    RETURNS
-    -------
-    Plots critique plots of the given darm model, and saves them in one pdf file.
-
-    NOTES
-    -----
-    I list some hard coded defaults that are not options of the method.
     """
     # See bp1 plot
     default_olg_yspan = 1e12
