@@ -26,17 +26,9 @@ from .model import Model
 class SensingModel(Model):
     """
     A sensing function model object
-
     This is a class to set up the model for the sensing function from a
     configuration file with all the information about where the data is stored
 
-    Parameters
-    ----------
-
-    Returns
-    -------
-
-
     """
 
     def __init__(self, config):
@@ -67,6 +59,7 @@ class SensingModel(Model):
         -------
         optical_response : `LTI object`
             coupled cavity optical response
+
         """
 
         cavity_pole = signal.ZerosPolesGain(
@@ -94,13 +87,11 @@ class SensingModel(Model):
         """
         Compute the mean arm length of the x and y arms
 
-        Parameters
-        ----------
-
         Returns
         -------
         mean_length : `float`
             mean arm length in units of meters
+
         """
 
         mean_length = np.mean(
@@ -127,6 +118,7 @@ class SensingModel(Model):
         response : `complex128`, array-like
             transfer function response of the analog transimpedence amplifier
             in path `name`
+
         """
 
         # Make sure that name is listed uniquely in self.omc_path_names
@@ -210,6 +202,7 @@ class SensingModel(Model):
         response : `complex128`, array-like
             transfer function response of the analog whitening electronics in
             path `name`
+
         """
 
         # Make sure that name is listed uniquely in self.omc_path_names
@@ -300,6 +293,7 @@ class SensingModel(Model):
         -------
         response : `complex128`, array-like
             transfer function response of the analog electronics in path `name`
+
         """
 
         # Make sure that name is listed uniquely in self.omc_path_names
@@ -350,6 +344,7 @@ class SensingModel(Model):
         filter_response : `complex128`, array-like
             transfer function response of the digital filters in the path
             labeled by `name`
+
         """
 
         idx = self.omc_path_names.index(name)
@@ -426,6 +421,7 @@ class SensingModel(Model):
         -------
         path_response : `complex128`, array-like
             transfer function response of the path labeled by `idx`
+
         """
 
         idx = self.omc_path_names.index(name)
@@ -479,6 +475,7 @@ class SensingModel(Model):
         -------
         combined_paths : `complex128`, array-like
             transfer function response
+
         """
 
         # Initialize the total weight to be 0
@@ -513,6 +510,7 @@ class SensingModel(Model):
         -------
         tf : `complex128`, array-like
             transfer function response
+
         """
 
         return np.exp(-2.0*np.pi*1j *
@@ -533,6 +531,7 @@ class SensingModel(Model):
         -------
         tf : `complex128`, array-like
             transfer function response
+
         """
 
         return np.exp(-2.0*np.pi*1j *
@@ -555,6 +554,7 @@ class SensingModel(Model):
         -------
         C_res : `complex128`, array-like
             transfer function response
+
         """
 
         C_res = (self.sensing_sign *
@@ -578,6 +578,7 @@ class SensingModel(Model):
         -------
         tf : `complex128`, array-like
             transfer function response of the sensing function
+
         """
 
         # coupled cavity response without the optical gain
@@ -625,6 +626,7 @@ class SensingModel(Model):
         -------
         sensingProducts : namedtuple
             namedtuple of all the intermediate data products
+
         """
         sensingProducts = \
             namedtuple('sensingProducts',
