@@ -107,8 +107,8 @@ class DARMUncertainty(object):
             self._config = configparser.ConfigParser(
                 comment_prefixes=('#',), inline_comment_prefixes=('#',))
 
-        if os.path.exists(config):
-            with open(config) as f:
+        if os.path.exists(os.path.normpath(config)):
+            with open(os.path.normpath(config)) as f:
                 self._config.read_file(f)
         else:
             self._config.read_string(config)
@@ -923,7 +923,8 @@ class DARMUncertainty(object):
         return tf, data
 
     def compute_response_uncertainty(self, gpstime, frequencies, trials=1000,
-                                     data=None, save_to_file=None):
+                                     data=None, shift_sample_tf=None,
+                                     save_to_file=None):
         """
         This method samples the response function uncertainty a number of times
         in order to obtain an estimate of the systematic error and associated
@@ -947,6 +948,12 @@ class DARMUncertainty(object):
             pipeline. If this is not provided, or it does not match the GPS
             time and duration, then it will be queried. A LIGO.ORG credential
             will be required
+        shift_sample_tf : `complex`, array-like, optional
+            Multiply sampled responses by a transfer function. The transfer
+            function needs to be computed from the same frequenices as this
+            method uses otherwise results are unpredictable
+        save_to_file : `str`, optional
+            Path to file saved as HDF5 (.h5 or .hdf5) or ASCII (.txt)
 
         Returns
         -------
@@ -991,6 +998,10 @@ class DARMUncertainty(object):
                 for j, stage in enumerate(act_syserr_dict[arm].keys()):
                     act_syserr_samples[arm][stage][n, :] = act_syserr_dict[arm][stage]
 
+            if shift_sample_tf is not None:
+                assert len(frequencies) == len(shift_sample_tf)
+                response_samples[n, :] *= shift_sample_tf
+
         # Save the draws to a file if requested
         # TODO: do we need to use astropy.table.Table in HDF5? The O3 version used it
         # TODO: what else is required to be saved into these files? The O3
@@ -998,6 +1009,7 @@ class DARMUncertainty(object):
         if save_to_file is not None:
             if (os.path.splitext(save_to_file) == '.h5' or
                     os.path.splitext(save_to_file) == '.hdf5'):
+                save_to_file = os.path.normpath(save_to_file)
                 with h5py.File(save_to_file, 'r') as f:
                     f.create_dataset('config', data=self._config)
                     f.create_dataset('deltaR/freq', data=frequencies)
@@ -1012,6 +1024,7 @@ class DARMUncertainty(object):
                         for j, stage in enumerate(act_syserr_samples[arm].keys()):
                             f.create_dataset(f'GPR/{arm}/{stage}',
                                              data=act_syserr_samples[arm][stage])
+                    f.create_dataset('shift_sample_tf', data=shift_sample_tf)
             elif (os.path.splitext(save_to_file) == '.txt'):
                 response_mag_quant, response_pha_quant = \
                     self.response_quantiles(response_samples)
