@@ -20,6 +20,7 @@ from numpy.polynomial import polynomial as P
 from collections import namedtuple
 import re
 import h5py
+from os.path import normpath
 
 cds_filter = namedtuple('cds_filter', ['name', 'soscoef', 'fs', 'design'])
 cds_filter_bank = namedtuple('cds_filter_bank',
@@ -432,7 +433,7 @@ def read_filter_file(filename):
         Data from the FOTON filter file
     """
     out = [filename]
-    with open(filename) as file:
+    with open(normpath(filename)) as file:
         for line in file:
             line = line.rstrip()
             if (re.match('^#', line) and len(line) > 2 and not
@@ -570,7 +571,7 @@ def save_chain_to_hdf5(filename, meas_model, fmin, fmax, measurement, chain):
         The MCMC chain
     """
 
-    with h5py.File(filename, 'w') as f:
+    with h5py.File(normpath(filename), 'w') as f:
         f.create_dataset('measurement_model', data=str(meas_model))
         f.create_dataset('fmin', data=fmin)
         f.create_dataset('fmax', data=fmax)
@@ -603,7 +604,7 @@ def read_chain_from_hdf5(filename):
         The MCMC chain
     """
 
-    with h5py.File(filename, 'r') as f:
+    with h5py.File(normpath(filename), 'r') as f:
         meas_model = f.get('measurement_model')[()].decode('utf-8')
         fmin = f.get('fmin')[()]
         fmax = f.get('fmax')[()]
@@ -633,7 +634,8 @@ def save_gpr_to_hdf5(filename, meas_model, measurement, y_pred, cov,
     frequencies : `float`, array-like
         Array of frequencies the GPR is valid for
     """
-    with h5py.File(filename, 'w') as f:
+
+    with h5py.File(normpath(filename), 'w') as f:
         if measurement == 'sensing' or 'actuation' in measurement:
             group = f.create_group(measurement)
         else:
@@ -667,7 +669,8 @@ def read_gpr_from_hdf5(filename, measurement):
     frequencies : `float`, array-like
         Array of frequencies the GPR is valid for
     """
-    with h5py.File(filename, 'r') as f:
+
+    with h5py.File(normpath(filename), 'r') as f:
         assert measurement == list(f.keys())[0], f'{measurement} is not an hdf5 group in {filename}'
 
         meas = f.get(measurement)
@@ -701,7 +704,7 @@ def read_eta_or_syserr_from_hdf5(filename, measurement=None, sensing=False, actu
         dictionary of systematic error for this arm and stage
     """
 
-    with h5py.File(filename, 'r') as f:
+    with h5py.File(normpath(filename), 'r') as f:
 
         if measurement is not None:
             assert measurement == \
@@ -721,3 +724,33 @@ def read_eta_or_syserr_from_hdf5(filename, measurement=None, sensing=False, actu
                     syserr[arm][stage] = f.get(f'{arm}/{stage}')[()]
 
     return frequencies, syserr
+
+
+def thiran_delay_filter(tau, Ts):
+    """Create a frequency response Thiran Delay Filter
+
+    Parameters
+    ----------
+    tau : `float`
+        time delay(secod)
+    Ts : `float`
+       sample time(second)
+
+    Returns
+    ----------
+    sys : :obj:`scipy.signal.TransferFunction`
+    """
+
+    D = tau/Ts
+    N = np.math.ceil(D)
+
+    a = []
+    for k in range(1, N+1):
+        INI = 1
+        for i in range(N+1):
+            INI = INI*(D-N+i)/(D-N+k+i)
+        a.append(((-1)**k)*(np.math.factorial(N)/(np.math.factorial(k)*np.math.factorial(N-k)))*INI)
+    a.insert(0, 1)
+    aa = a[::-1]
+    sys = signal.TransferFunction(aa, a, dt=Ts)
+    return sys
