@@ -1048,7 +1048,7 @@ foton_delay_filter_tf = test/H1CALCS_8_CLK_DELAY.txt
 
     def test_deltal_ext_pcal_corrrection(self):
         calcs = pydarm.calcs.CALCSModel(self.model_string)
-        deltal_ext_pcal = calcs.deltal_ext_pcal_corrrection(self.frequencies)
+        deltal_ext_pcal = calcs.deltal_ext_pcal_correction(self.frequencies)
         for n in range(len(self.frequencies)):
             self.assertAlmostEqual(
                 np.abs(deltal_ext_pcal[n] /
