@@ -296,7 +296,7 @@ class TestComputeEpicsRecords(unittest.TestCase):
 
     def setUp(self):
         self.frequencies = np.array(
-            [17.1, 15.6, 16.4, 17.6, 410.3, 1083.7])
+            [17.1, 15.6, 16.4, 17.6, 410.3, 1083.7, 500.1, 500.1])
         self.known_epics = {
             'CAL-CS_TDEP_PCAL_LINE1_CORRECTION':
             0.003384106838174459+0.0004044180029064908j,
@@ -330,6 +330,10 @@ class TestComputeEpicsRecords(unittest.TestCase):
             4.078008711853952e-17+4.992745126138772e-18j,
             'CAL-CS_TDEP_PCAL_LINE3_CORRECTION':
             8.319363469674813e-07+1.1949591405958398e-07j,
+            'CAL-CS_TDEP_PCAL_X_COMPARE_CORRECTION':
+            -3.978067573573798e-06-2.6500091829175134e-07j,
+            'CAL-CS_TDEP_PCAL_Y_COMPARE_CORRECTION':
+            3.978067573573798e-06+2.6500091829175134e-07j,
             'CAL-CS_TDEP_SUS_LINE1_SUS_DEMOD_PHASE': -0.3427734375,
             'CAL-CS_TDEP_SUS_LINE2_SUS_DEMOD_PHASE': -0.36035156249999994,
             'CAL-CS_TDEP_SUS_LINE3_SUS_DEMOD_PHASE': -0.38671875}
@@ -437,7 +441,7 @@ digital_filter_gain = 400,1
         test_epics = darm.compute_epics_records(
             self.frequencies[0], self.frequencies[1], self.frequencies[2],
             self.frequencies[3], self.frequencies[4], self.frequencies[5],
-            arm='x', endstation=True)
+            self.frequencies[6], self.frequencies[7], endstation=True)
         for idx, (key, val) in enumerate(self.known_epics.items()):
             self.assertAlmostEqual(
                 np.abs(test_epics[key]/self.known_epics[key]), 1.0, places=6)
