@@ -1077,6 +1077,139 @@ anti_aliasing_method      = biquad
                 places=2)
 
 
+class TestCompareProcessedTSTResponse(unittest.TestCase):
+
+    def setUp(self):
+        # These are the xml files we want to get our data from, and compare against.
+        meas_file_1 = \
+            'test/2019-04-24_H1SUSETMX_L3_iEXC2DARM_8min.xml'
+        meas_file_2 = \
+            'test/2019-04-24_H1SUSETMX_L3_PCAL2DARM_8min.xml'
+
+        # This is the model that we need to use in order to process the data.
+        self.model_string = '''
+[metadata]
+[interferometer]
+[actuation_x_arm]
+darm_feedback_sign = -1
+uim_NpA       = 1.634
+pum_NpA       = 0.02947
+tst_NpV2      = 4.427e-11
+linearization = OFF
+actuation_esd_bias_voltage = -9.3
+sus_filter_file = test/H1SUSETMX_1256232808.txt
+tst_isc_inf_bank    = ETMX_L3_ISCINF_L
+tst_isc_inf_modules =
+tst_isc_inf_gain    = 1.0
+tst_lock_bank       = ETMX_L3_LOCK_L
+tst_lock_modules    = 5,8,9,10
+tst_lock_gain       = 1.0
+tst_drive_align_bank     = ETMX_L3_DRIVEALIGN_L2L
+tst_drive_align_modules  = 4,5
+tst_drive_align_gain     = -35.7
+pum_lock_bank    = ETMX_L2_LOCK_L
+pum_lock_modules = 7
+pum_lock_gain    = 23.0
+pum_drive_align_bank    = ETMX_L2_DRIVEALIGN_L2L
+pum_drive_align_modules = 6,7
+pum_drive_align_gain    = 1.0
+pum_coil_outf_signflip  = 1
+uim_lock_bank    = ETMX_L1_LOCK_L
+uim_lock_modules = 10
+uim_lock_gain    = 1.06
+uim_drive_align_bank    = ETMX_L1_DRIVEALIGN_L2L
+uim_drive_align_modules =
+uim_drive_align_gain    = 1.0
+suspension_file = test/H1susdata_O3.mat
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_driver_DC_gain_VpV_HV = 40
+tst_driver_DC_gain_VpV_LV = 1.881
+pum_driver_DC_trans_ApV = 2.6847e-4
+uim_driver_DC_trans_ApV = 6.1535e-4
+anti_imaging_rate_string = 16k
+anti_imaging_method      = biquad
+analog_anti_imaging_file = test/H1aa.mat
+dac_gain = 7.62939453125e-05
+unknown_actuation_delay = 15e-6
+[pcal]
+pcal_dewhiten               = 1.0, 1.0
+ref_pcal_2_darm_act_sign    = -1.0
+analog_anti_aliasing_file = test/H1aa.mat
+anti_aliasing_rate_string = 16k
+anti_aliasing_method      = biquad
+'''
+        meas1 = pydarm.measurement.Measurement(meas_file_1)
+        meas2 = pydarm.measurement.Measurement(meas_file_2)
+        process_sensing = \
+            pydarm.measurement.ProcessActuationMeasurement(
+                self.model_string, 'actuation_x_arm', meas1, meas2,
+                ('H1:SUS-ETMX_L3_CAL_EXC', 'H1:LSC-DARM_IN1_DQ'),
+                ('H1:CAL-PCALY_RX_PD_OUT_DQ', 'H1:LSC-DARM_IN1_DQ'),
+                meas1_cohThresh=0.9, meas2_cohThresh=0.9)
+
+        known_freq, processed_tst_resp, known_tf_unc = \
+            process_sensing.get_processed_measurement_response()
+        self.known_freq = known_freq
+        self.known_tf_mag = np.abs(processed_tst_resp)
+        self.known_tf_angle = np.angle(processed_tst_resp, deg=True)
+        self.known_tf_unc = known_tf_unc
+
+    def tearDown(self):
+        del self.model_string
+        del self.known_freq
+        del self.known_tf_mag
+        del self.known_tf_angle
+        del self.known_tf_unc
+
+    def test_get_processed_tst_response(self):
+        """ Test the hdf5 processing of the TST response """
+
+        # These are the hdf5 files we want to get our data from.
+        meas_file_1 = \
+            'test/2019-04-24_H1SUSETMX_L3_iEXC2DARM.hdf5'
+        meas_file_2 = \
+            'test/2019-04-24_H1SUSETMX_L3_PCAL2DARM.hdf5'
+
+        meas1 = pydarm.measurement.Measurement(meas_file_1)
+        meas2 = pydarm.measurement.Measurement(meas_file_2)
+        process_sensing = \
+            pydarm.measurement.ProcessActuationMeasurement(
+                self.model_string, 'actuation_x_arm', meas1, meas2,
+                ('H1:SUS-ETMX_L3_CAL_EXC', 'H1:LSC-DARM_IN1_DQ'),
+                ('H1:CAL-PCALY_RX_PD_OUT_DQ', 'H1:LSC-DARM_IN1_DQ'),
+                meas1_cohThresh=0.9, meas2_cohThresh=0.9)
+
+        freq, processed_tst_resp, processed_tst_resp_unc = \
+            process_sensing.get_processed_measurement_response()
+
+        for n in range(len(self.known_freq)):
+            # Test absolute differences
+            self.assertAlmostEqual(freq[n], self.known_freq[n], places=3)
+            self.assertAlmostEqual(np.abs(processed_tst_resp[n]),
+                                   self.known_tf_mag[n])
+            self.assertAlmostEqual(np.angle(processed_tst_resp[n], deg=True),
+                                   self.known_tf_angle[n], places=3)
+            self.assertAlmostEqual(processed_tst_resp_unc[n],
+                                   self.known_tf_unc[n], places=5)
+            # Test relative differences
+            self.assertAlmostEqual(freq[n] / self.known_freq[n], 1.0, places=4)
+            self.assertAlmostEqual(
+                np.abs(processed_tst_resp[n]) / self.known_tf_mag[n], 1.0,
+                places=4)
+            self.assertAlmostEqual(np.angle(processed_tst_resp[n], deg=True) /
+                                   self.known_tf_angle[n], 1.0, places=2)
+            self.assertAlmostEqual(
+                processed_tst_resp_unc[n] / self.known_tf_unc[n], 1.0,
+                places=2)
+
+
 class TestGetProcessedPUMResponse(unittest.TestCase):
 
     def setUp(self):
