@@ -406,17 +406,7 @@ class TestComputeResponseUncertainty(unittest.TestCase):
     def setUp(self):
         self.data = tsd.read('./test/test_ch_data.hdf5')
         self.frequencies = np.logspace(0, np.log10(5000.), 10)
-
-        self.known_ratio = np.ones(len(self.frequencies), dtype='complex128')
-        os.environ['CAL_DATA_ROOT'] = './test'
-
-    def tearDown(self):
-        del self.data
-        del self.frequencies
-        del os.environ['CAL_DATA_ROOT']
-
-    def test_compute_response_uncertainty(self):
-        config = '''[sensing-measurement-files]
+        self.config = '''[sensing-measurement-files]
 mcmc = 
 gpr = 
 [x-arm-measurement-files]
@@ -470,8 +460,19 @@ sys_err =
 sys_unc =
 sample = False'''
 
+        self.known_ratio = np.ones(len(self.frequencies), dtype='complex128')
+        os.environ['CAL_DATA_ROOT'] = './test'
+
+    def tearDown(self):
+        del self.data
+        del self.frequencies
+        del os.environ['CAL_DATA_ROOT']
+        del self.known_ratio
+        del self.config
+
+    def test_compute_response_uncertainty(self):
         test_unc = pydarm.uncertainty.DARMUncertainty(
-            'example_model_files/H1_20190416.ini', config)
+            'example_model_files/H1_20190416.ini', self.config)
         
         samples = test_unc.compute_response_uncertainty(
             1239958818, self.frequencies, trials=1, data=self.data)
@@ -484,6 +485,22 @@ sample = False'''
                 np.angle(samples[0][n], deg=True) -
                 np.angle(self.known_ratio[n], deg=True), 0.0, places=5)
 
+    def test_compute_response_uncertainty_shift(self):
+        test_unc = pydarm.uncertainty.DARMUncertainty(
+            'example_model_files/H1_20190416.ini', self.config)
+        
+        samples = test_unc.compute_response_uncertainty(
+            1239958818, self.frequencies, trials=1, data=self.data,
+            shift_sample_tf=1.1*np.ones(len(self.frequencies), dtype='complex128'))
+
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(
+                np.abs(samples[0][n]) / np.abs(self.known_ratio[n]), 1.1,
+                places=6)
+            self.assertAlmostEqual(
+                np.angle(samples[0][n], deg=True) -
+                np.angle(self.known_ratio[n], deg=True), 0.0, places=5)
+
 
 class TestResponseQuantiles(unittest.TestCase):
 
